ConfigLoader class

Constructors

ConfigLoader()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

load({String? workingDirectory, String? homeDirectory, Logger? log}) → Map<String, dynamic>?
loadAnalysisOptions({String? workingDirectory, String? homeDirectory, Logger? log}) → Map<String, dynamic>?
Loads the top-level analysis_options section from rekeens.yaml.
loadHooks({String? workingDirectory, String? homeDirectory, Logger? log}) → HookSet
Loads the top-level hooks section from rekeens.yaml.