HookRunner class

Executes shell commands defined as hooks in rekeens.yaml.

Constructors

HookRunner({Logger? log, String? workingDirectory})

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
runHooks(List<HookConfig> hooks, HookContext context) → Future<void>
Runs hooks that apply to context.generatorType.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited