HookSet class

The set of hooks for a single lifecycle point (before/after generate).

Constructors

HookSet({List<HookConfig> beforeGenerate = const [], List<HookConfig> afterGenerate = const []})
const

Properties

afterGenerate → List<HookConfig>
final
beforeGenerate → List<HookConfig>
final
hashCode → int
The hash code for this object.
no setterinherited
isEmpty → bool
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited