ProjectFileWriter class

Constructors

ProjectFileWriter({TemplateService? templateService, TemplateResolver? templateResolver, String? workingDirectory, String? templatesRootOverride})

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
templatesRootOverride → String?
final
workingDirectory → String?
final

Methods

configureProjectFiles(String projectName, Map<String, dynamic> options) → Future<void>
enableFlutterGenerate(String projectName) → Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited