ProcessTimeouts class
Timeout constants for external process invocations.
These are conservative upper bounds — under normal conditions the commands finish well within these limits. If a process exceeds its timeout it is forcefully terminated and a TimeoutException is thrown so the CLI does not hang indefinitely without feedback.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited