TemplateService class

Constructors

TemplateService()
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyTemplate({required String sourceDir, required String targetDir, required Map<String, String> variables, Map<String, bool>? conditions, Map<String, List<Map<String, String>>>? lists}) → Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
renderContent(String content, Map<String, String> variables, {Map<String, bool>? conditions, Map<String, List<Map<String, String>>>? lists}) → String
renderFile({required String sourcePath, required String targetPath, required Map<String, String> variables, Map<String, bool>? conditions, Map<String, List<Map<String, String>>>? lists}) → Future<void>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited