HookContext class
Context passed to HookRunner — the generator invocation details.
Constructors
- HookContext({required String generatorType, required String featureName, String? entityName, bool dryRun = false})
-
const
Properties
- dryRun → bool
-
final
- entityName → String?
-
final
- featureName → String
-
final
- generatorType → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited