Preset class
Constructors
-
Preset({required String name, required List<
String> platforms, required String architecture, required String stateManagement, required String router, required String networking, required String storage, required bool localization, required String theme, String seedColor = '0xFF2196F3', String fontFamily = '', bool codegen = false, bool pinVersions = false}) -
const
Properties
- architecture → String
-
final
- codegen → bool
-
final
- fontFamily → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- localization → bool
-
final
- name → String
-
final
- networking → String
-
final
- pinVersions → bool
-
final
-
platforms
→ List<
String> -
final
- router → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- seedColor → String
-
final
- stateManagement → String
-
final
- storage → String
-
final
- theme → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toOptions(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited