ProjectScaffolder class
Constructors
- ProjectScaffolder({TemplateService? templateService, TemplateResolver? templateResolver, ProjectFileWriter? projectFileWriter, ScaffoldProcessRunner? processRunner, Logger? log, String? workingDirectory})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
scaffold(
String projectName, Map< String, dynamic> options) → Future<void> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited